"""Add Import EdgePort and L3 Core Service workflows..

Revision ID: 7412c5b7ebe4
Revises: e1659d366925
Create Date: 2024-10-17 13:10:38.551706

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = '7412c5b7ebe4'
down_revision = 'e1659d366925'
branch_labels = None
depends_on = None


from orchestrator.migrations.helpers import create_workflow, delete_workflow

new_workflows = [
    {
        "name": "create_edge_port",
        "target": "CREATE",
        "description": "Create Edge Port",
        "product_type": "EdgePort"
    },
    {
        "name": "modify_edge_port",
        "target": "MODIFY",
        "description": "Modify Edge Port",
        "product_type": "EdgePort"
    },
    {
        "name": "terminate_edge_port",
        "target": "TERMINATE",
        "description": "Terminate Edge Port",
        "product_type": "EdgePort"
    },
    {
        "name": "validate_edge_port",
        "target": "SYSTEM",
        "description": "Validate Edge Port Configuration",
        "product_type": "EdgePort"
    },
    {
        "name": "create_imported_edge_port",
        "target": "CREATE",
        "description": "Import Edge Port",
        "product_type": "ImportedEdgePort"
    },
    {
        "name": "import_edge_port",
        "target": "MODIFY",
        "description": "Import Edge Port",
        "product_type": "ImportedEdgePort"
    },
    {
        "name": "create_nren_l3_core_service",
        "target": "CREATE",
        "description": "Create NREN L3 Core Service",
        "product_type": "NRENL3CoreService"
    },
    {
        "name": "modify_nren_l3_core_service",
        "target": "MODIFY",
        "description": "Modify NREN L3 Core Service",
        "product_type": "NRENL3CoreService"
    },
    {
        "name": "create_imported_nren_l3_core_service",
        "target": "CREATE",
        "description": "Create imported NREN L3 Core Service",
        "product_type": "ImportedNRENL3CoreService"
    },
    {
        "name": "import_nren_l3_core_service",
        "target": "MODIFY",
        "description": "Import NREN L3 Core Service",
        "product_type": "ImportedNRENL3CoreService"
    },
    {
        "name": "migrate_nren_l3_core_service",
        "target": "MODIFY",
        "description": "Migrate NREN L3 Core Service",
        "product_type": "NRENL3CoreService"
    }
]


def upgrade() -> None:
    conn = op.get_bind()
    for workflow in new_workflows:
        create_workflow(conn, workflow)


def downgrade() -> None:
    conn = op.get_bind()
    for workflow in new_workflows:
        delete_workflow(conn, workflow["name"])
